@@ -32,7 +32,7 @@ import mimetypes
 mimetypes.add_type('application/x-asciinema-recording', '.cast')
 
 
-class PrefixMiddleware(object):
+class PrefixMiddleware:
     def __init__(self, app, prefix=''):
         self.app = app
         self.prefix = prefix
@@ -44,7 +44,7 @@ class PrefixMiddleware(object):
             return self.app(environ, start_response)
         else:
             start_response('404', [('Content-Type', 'text/plain')])
-            return ['This URL does not belong to the bepasty app.'.encode()]
+            return [b'This URL does not belong to the bepasty app.']
 
 
 def setup_secret_key(app):
