@@ -37,7 +37,7 @@ from .hashing import compute_hash, hash_new
 MAX_FILENAME_LENGTH = 250
 
 
-class Upload(object):
+class Upload:
     _filename_re = re.compile(r'[^a-zA-Z0-9 *+:;.,_-]+')
     _type_re = re.compile(r'[^a-zA-Z0-9/+.-]+')
 
